/**
 * nmcDateRanger jQuery plugin - v1.0.0
 * Author: Patrick Clarke
 * Copyright (c) 2010 New Media Campaigns
 * Licenced under the MIT license
 * http://www.newmediacampaigns.com
**/
(function($){
	$.fn.nmcDateRanger = function(settings){
		settings = $.extend(true, {
			startDate: null,
			endDate: null,
			output: 'radio' // Valid Options include 'radio','checkbox' and 'dropdown'
		}, settings);

		return $(this).each(function(){
			
			$container = $(this);
			$dateRange = settings.startDate + ', ' + settings.endDate;
			var dates = $($dateRange).datepicker({
				defaultDate: "+1d",
				changeMonth: false,
				numberOfMonths: 1,
				onSelect: function(selectedDate) {
					var option = this.id == "start_date" ? "minDate" : "maxDate";
					var instance = $(this).data("datepicker");
					var date = $.datepicker.parseDate(instance.settings.dateFormat || $.datepicker._defaults.dateFormat, selectedDate, instance.settings);
					dates.not(this).datepicker("option", option, date);
					dateChanged($container);
				}
			});
		});

		var startDate, endDate;

		function dateChanged(container) {
			var sdText = $(settings.startDate).val();
			var edText = $(settings.endDate).val();
			if (sdText && edText && validateDateRange(sdText, edText)){
				setTimeout(createContent(settings.output, container), 1); // so datepicker can close
			}
		}

		function validateDateRange(sdText, edText) {
			startDate = new Date(sdText);
			endDate = new Date(edText);
			return (startDate instanceof Date && endDate instanceof Date && startDate <= endDate);
		}

		function createContent(type, container){
			if(type == 'checkbox')
				var output = buildCheckboxList();
			else if(type == 'dropdown')
				var output = buildDropDown();
			else if(type == 'radio')
				var output = buildRadioList();
			else{}
			if( output != null)
				$(container).html(output.join(""));
		}

		function formatDate(date, separator) {
			return ("00" + (date.getMonth() + 1)).slice(-2) + separator + ("00" + date.getDate()).slice(-2) + separator + date.getFullYear();
		}

		function buildDropDown(){
			var parts = ["<select class='dates-dropdown' name='event-date'>"];
			while (startDate <= endDate) {
				var dateId = formatDate(startDate, "");
				parts.push("<option type='text' name='cater"+dateId+"' value='" + formatDate(startDate, "/") +"'>" + formatDate(startDate, "/") +"</option>");
				startDate.setTime(startDate.getTime() + 86400000);
			} 
			parts.push("</select>"); 
			return parts;
		}

		function buildRadioList(){
			var parts = ['<ul class="dates-radio-list">'];
			while (startDate <= endDate){
				var dateId = formatDate(startDate,"/");
				parts.push('<li><input name="select-date" type="radio" value='+dateId+'/> '+dateId+'</li>');
				startDate.setTime(startDate.getTime() + 86400000);
			}
			parts.push("</ul>");
			return parts;
		}

		function buildCheckboxList(){
			var parts = ['<ul class="dates-checkbox-list">'];
			while (startDate <= endDate){
				var dateId = formatDate(startDate,"");
				var dateName = formatDate(startDate,"/");
				parts.push('<li><input type="checkbox" name="date-'+dateId+'" value="'+dateName+'" /> '+dateName+'</li>');
				startDate.setTime(startDate.getTime() + 86400000);
			}
			parts.push("</ul>");
			return parts;
		}
	};
})(jQuery);